@@ -1,5 +1,5 @@
 /* cfg.h --- Configuration file functions.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2010  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -25,6 +25,8 @@
 /* Get prototypes. */
 #include "cfg.h"
 
+#include "low-crypto.h"
+
 #define KDC_SERVICE_PORT "\x6b\x65\x72\x62\x65\x72\x6f\x73"
 
 enum
@@ -45,6 +47,7 @@ enum
   VERBOSE_NOISE_OPTION,
   VERBOSE_OPTION,
   STRINGPROCESS_OPTION,
+  QUICK_RANDOM,
   THE_END
 };
 
@@ -65,6 +68,7 @@ static const char * const _shishi_opts[] = {
   /* [VERBOSE_NOISE_OPTION] =        */ "verbose-noise",
   /* [VERBOSE_OPTION] =              */ "verbose",
   /* [STRINGPROCESS_OPTION] =        */ "stringprocess",
+  /* [QUICK_RANDOM] =                */ "quick-random",
   /* [THE_END] =                     */ NULL
 };
 
@@ -186,8 +190,7 @@ shishi_cfg (Shishi * handle, const char *option)
 		if (handle->realminfos[i].nkdcaddresses > 0 ||
 		    handle->realminfos[i].kdcaddresses)
 		  {
-		    if (handle->realminfos[i].kdcaddresses)
-		      free (handle->realminfos[i].kdcaddresses);
+		    free (handle->realminfos[i].kdcaddresses);
 		    handle->realminfos[i].kdcaddresses = NULL;
 		    handle->realminfos[i].nkdcaddresses = 0;
 		  }
@@ -234,11 +237,14 @@ shishi_cfg (Shishi * handle, const char *option)
 	  break;
 
 	case STRINGPROCESS_OPTION:
-	  if (handle->stringprocess)
-	    free (handle->stringprocess);
+	  free (handle->stringprocess);
 	  handle->stringprocess = xstrdup (value);
 	  break;
 
+	case QUICK_RANDOM:
+	  _shishi_quick_random ();
+	  break;
+
 	case VERBOSE_OPTION:
 	  handle->verbose = value && atoi (value) ? atoi (value) :
 	    ~0 & ~VERBOSES;
@@ -397,8 +403,7 @@ shishi_cfg_from_file (Shishi * handle, const char *cfg)
       shishi_cfg (handle, p);
     }
 
-  if (line)
-    free (line);
+  free (line);
 
   if (ferror (fh))
     shishi_error_printf (handle, "Error reading configuration file");
